@@ -71,7 +71,7 @@ class SynologyFileCache():
         if not self._exist(file_path=cache_path):
             self.create_folder(folder_path=cache_path)
 
-        if os.path.isfile(file_path):
+        if not isinstance(file_path, list) and os.path.isfile(file_path):
             new_file_path = os.path.join(os.path.dirname(file_path), key)
             if file_path != new_file_path:
                 shutil.copyfile(file_path, new_file_path)
